pub enum FontStyle {
Normal,
Italic,
Oblique(Option<f32>),
}Expand description
Visual slant of a font.
Mirrors parley/fontique’s FontStyle (see parley::FontStyle).
Variants
Normal
An upright or “roman” style. Default.
Italic
A slanted style, generally with a different structure from the normal style.
Oblique(Option<f32>)
A slanted style derived from the normal style, with an optional angle
in degrees (None uses the engine-specific default angle).